@@ -1,5 +1,5 @@
 /*
- * Copyright (C) Pedram Pourang (aka Tsu Jan) 2014-2022 <tsujan2000@gmail.com>
+ * Copyright (C) Pedram Pourang (aka Tsu Jan) 2014-2024 <tsujan2000@gmail.com>
  *
  * Kvantum is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -23,10 +23,6 @@
 #include <QWindow>
 
 #ifdef NO_KF
-#if (QT_VERSION < QT_VERSION_CHECK(6,0,0))
-#include <QVector>
-#include <QX11Info>
-#endif
 #include <QApplication>
 #include <X11/Xlib.h>
 #include <X11/Xatom.h>
@@ -44,14 +40,10 @@ BlurHelper::BlurHelper (QObject* parent, QList<qreal> menuS, QList<qreal> toolti
   isX11_ = (QString::compare(QGuiApplication::platformName(), "xcb", Qt::CaseInsensitive) == 0);
   if (isX11_)
   {
-#if (QT_VERSION < QT_VERSION_CHECK(6,0,0))
-    atom_blur_ = XInternAtom (QX11Info::display(), "_KDE_NET_WM_BLUR_BEHIND_REGION", False);
-#else
     if (auto x11NativeInterfce = qApp->nativeInterface<QNativeInterface::QX11Application>())
       atom_blur_ = XInternAtom (x11NativeInterfce->display(), "_KDE_NET_WM_BLUR_BEHIND_REGION", False);
     else
       atom_blur_ = None;
-#endif
   }
   else
     atom_blur_ = None;
@@ -278,16 +270,11 @@ void BlurHelper::update (QWidget* widget) const
     if (!widget->internalWinId())
       return;
     Display *display = nullptr;
-#if (QT_VERSION < QT_VERSION_CHECK(6,0,0))
-    QVector<unsigned long> data;
-    display = QX11Info::display();
-#else
-    QList<unsigned long> data;
     if (auto x11NativeInterfce = qApp->nativeInterface<QNativeInterface::QX11Application>())
       display = x11NativeInterfce->display();
-#endif
     if (display == nullptr)
       return;
+    QList<unsigned long> data;
     for (QRegion::const_iterator it = region.begin(); it != region.end(); ++ it)
     {
       data << (*it).x() << (*it).y() << (*it).width() << (*it).height();
@@ -324,16 +311,9 @@ void BlurHelper::clear (QWidget* widget) const
 #ifdef NO_KF
   if (!isX11_)
     return;
-#endif
-
-#ifdef NO_KF
   Display *display = nullptr;
-#if (QT_VERSION < QT_VERSION_CHECK(6,0,0))
-  display = QX11Info::display();
-#else
   if (auto x11NativeInterfce = qApp->nativeInterface<QNativeInterface::QX11Application>())
     display = x11NativeInterfce->display();
-#endif
   if (display && widget->internalWinId())
     XDeleteProperty (display, widget->internalWinId(), atom_blur_);
 #else
